@@ -18,7 +18,6 @@
 # along with Paramiko; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 
-import os.path
 import random
 import socket
 # import sys
@@ -28,13 +27,13 @@ import paramiko
 
 from binascii import hexlify
 from paramiko.py3compat import u, decodebytes
-from webssh.settings import base_dir
+from tests.utils import make_tests_data_path
 
 
 # setup logging
-paramiko.util.log_to_file(os.path.join(base_dir, 'tests', 'sshserver.log'))
+paramiko.util.log_to_file(make_tests_data_path('sshserver.log'))
 
-host_key = paramiko.RSAKey(filename=os.path.join(base_dir, 'tests', 'test_rsa.key')) # noqa
+host_key = paramiko.RSAKey(filename=make_tests_data_path('test_rsa.key'))
 # host_key = paramiko.DSSKey(filename='test_dss.key')
 
 print('Read key: ' + u(hexlify(host_key.get_fingerprint())))
@@ -52,13 +51,12 @@ class Server(paramiko.ServerInterface):
             b'UWT10hcuO4Ks8=')
     good_pub_key = paramiko.RSAKey(data=decodebytes(data))
 
-    langs = ['en_US.UTF-8', 'zh_CN.GBK']
+    encodings = ['UTF-8', 'GBK', 'UTF-8\r\n', 'GBK\r\n']
 
     def __init__(self):
         self.shell_event = threading.Event()
         self.exec_event = threading.Event()
-        self.lang = random.choice(self.langs)
-        self.encoding = self.lang.split('.')[-1]
+        self.encoding = random.choice(self.encodings)
 
     def check_channel_request(self, kind, chanid):
         if kind == 'session':
@@ -67,26 +65,27 @@ class Server(paramiko.ServerInterface):
 
     def check_auth_password(self, username, password):
         print('Auth attempt with username: {!r} & password: {!r}'.format(username, password)) # noqa
-        if (username in ['robey', 'bar']) and (password == 'foo'):
+        if (username in ['robey', 'bar', 'foo']) and (password == 'foo'):
             return paramiko.AUTH_SUCCESSFUL
         return paramiko.AUTH_FAILED
 
     def check_auth_publickey(self, username, key):
         print('Auth attempt with username: {!r} & key: {!r}'.format(username, u(hexlify(key.get_fingerprint())))) # noqa
-        if (username == 'robey') and (key == self.good_pub_key):
+        if (username in ['robey', 'keyonly']) and (key == self.good_pub_key):
             return paramiko.AUTH_SUCCESSFUL
         return paramiko.AUTH_FAILED
 
     def get_allowed_auths(self, username):
+        if username == 'keyonly':
+            return 'publickey'
         return 'password,publickey'
 
     def check_channel_exec_request(self, channel, command):
-        if command != b'locale':
+        if command != b'locale charmap':
             ret = False
         else:
             ret = True
-            result = 'LANG={lang}\nLANGUAGE=\nLC_CTYPE="{lang}"\n'.format(lang=self.lang)  # noqa
-            channel.send(result)
+            channel.send(self.encoding)
             channel.shutdown(1)
         self.exec_event.set()
         return ret
@@ -147,14 +146,25 @@ def run_ssh_server(port=2200, running=True):
 
         # chan.send('\r\n\r\nWelcome!\r\n\r\n')
         print(server.encoding)
-        chan.send(banner.encode(server.encoding))
+        chan.send(banner.encode(server.encoding.strip()))
         if username == 'bar':
             msg = chan.recv(1024)
             chan.send(msg)
-
-        chan.close()
-        t.close()
-        client.close()
+        elif username == 'foo':
+            lst = []
+            while True:
+                msg = chan.recv(32 * 1024)
+                lst.append(msg)
+                if msg.endswith(b'\r\n\r\n'):
+                    break
+            data = b''.join(lst)
+            while data:
+                s = chan.send(data)
+                data = data[s:]
+        else:
+            chan.close()
+            t.close()
+            client.close()
 
     try:
         sock.close()
